@@ -24,7 +24,7 @@ use utf8;
 
 use FindBin qw($Bin);
 use lib "$Bin/../../lib";
-use Google::Ads::GoogleAds::GoogleAdsClient;
+use Google::Ads::GoogleAds::Client;
 use Google::Ads::GoogleAds::Utils::GoogleAdsHelper;
 use Google::Ads::GoogleAds::V2::Common::GenderInfo;
 use Google::Ads::GoogleAds::V2::Common::DeviceInfo;
@@ -283,8 +283,7 @@ if (abs_path($0) ne abs_path(__FILE__)) {
 }
 
 # Get Google Ads Client, credentials will be read from ~/googleads.properties.
-my $api_client =
-  Google::Ads::GoogleAds::GoogleAdsClient->new({version => "V2"});
+my $api_client = Google::Ads::GoogleAds::Client->new({version => "V2"});
 
 # By default examples are set to die on any server returned fault.
 $api_client->set_die_on_faults(1);
